==> opennms-webapp-1.7.3-sources.jar: org/opennms/web/group/WebGroupRepository.java <==
/*
 * This file is part of the OpenNMS(R) Application.
 *
 * OpenNMS(R) is Copyright (C) 2009 The OpenNMS Group, Inc.  All rights reserved.
 * OpenNMS(R) is a derivative work, containing both original code, included code and modified
 * code that was published under the GNU General Public License. Copyrights for modified
 * and included code are below.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * Original code base Copyright (C) 1999-2001 Oculan Corp.  All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * For more information contact:
 * OpenNMS Licensing       <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 */
package org.opennms.web.group;

/**
 * WebGroupRepository
 *
 * @author brozow
 */
public interface WebGroupRepository {
    
    boolean groupExists(String groupName);
    
    WebGroup getGroup(String groupName);
    
    void saveGroup(WebGroup group);

    void deleteGroup(String groupName);

    void renameGroup(String oldName, String newName);

}

==> opennms-webapp-1.8.13-sources.jar: org/opennms/web/group/WebGroupRepository.java <==
/*
 * This file is part of the OpenNMS(R) Application.
 *
 * OpenNMS(R) is Copyright (C) 2009 The OpenNMS Group, Inc.  All rights reserved.
 * OpenNMS(R) is a derivative work, containing both original code, included code and modified
 * code that was published under the GNU General Public License. Copyrights for modified
 * and included code are below.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * Original code base Copyright (C) 1999-2001 Oculan Corp.  All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 * For more information contact:
 * OpenNMS Licensing       <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 */
package org.opennms.web.group;

/**
 * WebGroupRepository
 *
 * @author brozow
 * @version $Id: $
 * @since 1.8.1
 */
public interface WebGroupRepository {
    
    /**
     * <p>groupExists</p>
     *
     * @param groupName a {@link java.lang.String} object.
     * @return a boolean.
     */
    boolean groupExists(String groupName);
    
    /**
     * <p>getGroup</p>
     *
     * @param groupName a {@link java.lang.String} object.
     * @return a {@link org.opennms.web.group.WebGroup} object.
     */
    WebGroup getGroup(String groupName);
    
    /**
     * <p>saveGroup</p>
     *
     * @param group a {@link org.opennms.web.group.WebGroup} object.
     */
    void saveGroup(WebGroup group);

    /**
     * <p>deleteGroup</p>
     *
     * @param groupName a {@link java.lang.String} object.
     */
    void deleteGroup(String groupName);

    /**
     * <p>renameGroup</p>
     *
     * @param oldName a {@link java.lang.String} object.
     * @param newName a {@link java.lang.String} object.
     */
    void renameGroup(String oldName, String newName);

}
